#[non_exhaustive]#[repr(u8)]pub enum AlternateHandling {
NonIgnorable = 0,
Shifted = 1,
}Expand description
What to do about characters whose comparison level can be varied dynamically.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonIgnorable = 0
Keep the characters whose level can be varied on the primary level.
Shifted = 1
Shift the characters at or below MaxVariable to the
quaternary level.